
// Game.cpp

// Implements the CGame class representing a single parsed game

#include "stdafx.h"
#include "Game.h"





///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// CPlayer:

CPlayer::CPlayer(const std::string & iName, const std::string & iID, bool iIsOnTurn) :
	Name(iName),
	ID(iID),
	IsOnTurn(iIsOnTurn)
{
	// Nothing needed yet
}





CPlayer::CPlayer(const CPlayer & iPlayer)
{
	CopyFrom(iPlayer);
}





void CPlayer::CopyFrom(const CPlayer & iSrc)
{
	Name = iSrc.Name;
	ID = iSrc.ID;
	IsOnTurn = iSrc.IsOnTurn;
}





///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// CGame:

CGame::CGame(const char * iURL, size_t iURLLen, const char * iPartieID, const char * iGameType, bool iIsMyTurn) :
	URL(iURL, iURLLen),
	Type(iGameType),
	IsMyTurn(iIsMyTurn),
	HasBeenNotified(false)
{
	if (iPartieID != NULL)
	{
		for (int i = 0;; i++)
		{
			if ((iPartieID[i] < '0') || (iPartieID[i] > '9'))
			{
				PartieID = std::string(iPartieID, i);
				break;
			}
		}  // for i - iPartieID[]
	}
}





CGame::CGame(const CGame & iSrc)
{
	CopyFrom(iSrc);
}




CGame::~CGame()
{
	// Nothing needed yet
}





void CGame::CopyFrom(const CGame & iSrc)
{
	URL = iSrc.URL;
	Type = iSrc.Type;
	PartieID = iSrc.PartieID;
	
	for (CPlayerPtrs::const_iterator itr = iSrc.Players.begin(); itr != iSrc.Players.end(); ++itr)
	{
		CPlayer * p = new CPlayer(**itr);
		Players.push_back(p);
	}  // for itr - iSrc.Players[]

	IsMyTurn = iSrc.IsMyTurn;
	HasBeenNotified = iSrc.HasBeenNotified;
}




std::string CGame::GetPlayersString(void)
{
	std::string res;
	for (CPlayerPtrs::iterator itr = Players.begin(); itr != Players.end(); ++itr)
	{
		if (!res.empty())
		{
			res += ", ";
		}
		res += (*itr)->Name;
	}  // for itr - Players[]
	return res;
}





void CGame::OpenInBrowser(void)
{
	std::string MyURL(URL);
	if (MyURL.empty())
	{
		return;
	}
	if (MyURL[0] == '\"')
	{
		MyURL.erase(0, 1);
	}
	if (MyURL[MyURL.length() - 1] == '\"')
	{
		MyURL.erase(MyURL.length() - 1);
	}
	if (MyURL.find("http://") != 0)
	{
		MyURL = std::string("http://www.boiteajeux.net/") + MyURL;
	}

	CoInitializeEx(NULL, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
	ShellExecuteA(NULL, NULL, MyURL.c_str(), NULL, NULL, SW_SHOWMAXIMIZED);
}




